aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/includes/functions_content.php
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2018-12-02 12:55:02 +0100
committerMarc Alexander <admin@m-a-styles.de>2018-12-02 19:50:09 +0100
commit087bf6fd35913152129eed97005953ac3979002a (patch)
treee3f7626a46a4819e4831fd46a84d88d76d3d7b76 /phpBB/includes/functions_content.php
parentfc27dc02b42e3afa98e96bdab0daf752c6cb9ccf (diff)
downloadforums-087bf6fd35913152129eed97005953ac3979002a.tar
forums-087bf6fd35913152129eed97005953ac3979002a.tar.gz
forums-087bf6fd35913152129eed97005953ac3979002a.tar.bz2
forums-087bf6fd35913152129eed97005953ac3979002a.tar.xz
forums-087bf6fd35913152129eed97005953ac3979002a.zip
[ticket/15893] Pass needed language class directly to format quote
PHPBB3-15893
Diffstat (limited to 'phpBB/includes/functions_content.php')
-rw-r--r--phpBB/includes/functions_content.php15
1 files changed, 8 insertions, 7 deletions
diff --git a/phpBB/includes/functions_content.php b/phpBB/includes/functions_content.php
index 8284aab6a4..a15a03f966 100644
--- a/phpBB/includes/functions_content.php
+++ b/phpBB/includes/functions_content.php
@@ -1762,13 +1762,14 @@ class bitfield
/**
* Formats the quote according to the given BBCode status setting
*
* @param bool $bbcode_status The status of the BBCode setting
* @param array $quote_attributes The attributes of the quoted post
* @param phpbb\textformatter\utils $text_formatter_utils Text formatter utilities
* @param parse_message $message_parser Message parser class
* @param string $message_link Link of the original quoted post
*/
-function phpbb_format_quote($bbcode_status, $quote_attributes, $text_formatter_utils, $message_parser, $message_link = '')
+function phpbb_format_quote($language, $message_parser, $text_formatter_utils, $bbcode_status, $quote_attributes, $message_link = '')
{
if ($bbcode_status)
{
@@ -1794,7 +1795,7 @@ function phpbb_format_quote($bbcode_status, $quote_attributes, $text_formatter_u
$message = $quote_string . $message;
$message = str_replace("\n", "\n" . $quote_string, $message);
- $message_parser->message = $quote_attributes['author'] . " " . $user->lang['WROTE'] . ":\n" . $message . "\n";
+ $message_parser->message = $quote_attributes['author'] . " " . $language->lang('WROTE') . ":\n" . $message . "\n";
}
if ($message_link)
@@ -1762,13 +1762,14 @@ class bitfield
* Formats the quote according to the given BBCode status setting
*
- * @param bool $bbcode_status The status of the BBCode setting
- * @param array $quote_attributes The attributes of the quoted post
- * @param phpbb\textformatter\utils $text_formatter_utils Text formatter utilities
- * @param parse_message $message_parser Message parser class
- * @param string $message_link Link of the original quoted post
+ * @param phpbb\language\language $language Language class
+ * @param parse_message $message_parser Message parser class
+ * @param phpbb\textformatter\utils_interface $text_formatter_utils Text formatter utilities
+ * @param bool $bbcode_status The status of the BBCode setting
+ * @param array $quote_attributes The attributes of the quoted post
+ * @param string $message_link Link of the original quoted post
*/